@@ -8,7 +8,7 @@
  *                patterns.
  *
  * Copyright   :  Written by and Copyright (C) 2001-2002, 2006 the
- *                Privoxy team. http://www.privoxy.org/
+ *                Privoxy team. https://www.privoxy.org/
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and
@@ -38,9 +38,7 @@
 #include "project.h"
 
 extern void free_http_request(struct http_request *http);
-#ifndef FEATURE_EXTENDED_HOST_PATTERNS
 extern jb_err init_domain_components(struct http_request *http);
-#endif
 extern jb_err parse_http_request(const char *req, struct http_request *http);
 extern jb_err parse_http_url(const char *url,
                              struct http_request *http,
@@ -55,7 +53,8 @@ extern int url_match(const struct pattern_spec *pattern,
 extern jb_err create_pattern_spec(struct pattern_spec *url, char *buf);
 extern void free_pattern_spec(struct pattern_spec *url);
 extern int match_portlist(const char *portlist, int port);
-extern jb_err parse_forwarder_address(char *address, char **hostname, int *port);
+extern jb_err parse_forwarder_address(char *address, char **hostname, int *port,
+                                      char **username, char **password);
 
 #endif /* ndef URLMATCH_H_INCLUDED */
 
